yt.frontends.stream.sample\_data.tetrahedral\_mesh module
=========================================================

.. automodule:: yt.frontends.stream.sample_data.tetrahedral_mesh
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
